Index: sky.h
===================================================================
--- sky.h	(revision 89)
+++ sky.h	(revision 90)
@@ -30,7 +30,7 @@
 Internal use.
 **/
 
-void raydium_sky_sphere_render(GLfloat x, GLfloat y, GLfloat z, int detail);
+void raydium_sky_sphere_render		(GLfloat x, GLfloat y, GLfloat z, int detail);
 /**
 Internal use.
 Calculates and draw the sphere. Also rotate it according the angles or orbit.
@@ -40,26 +40,26 @@
 /**
 Atmosphere are series of effects that intend to make the sky and the atmosphere of the game more realistic. As this is quite-beta state, only a orbital sky effect is available right now. 
 To activate/deactivate this series of effects, you should use:
-##raydium_atmosphere_enable## and ##raydium_atmosphere_disable## respectively.
+##raydium_sky_atmosphere_enable## and ##raydium_sky_atmosphere_disable## respectively.
 If you need to check if the atmosphere is activated or not, use 
 ##raydium_atmosphere_check##. The rest of the functions are internal and should
 not used by normal programs.
 
 **/
 
-void raydium_atmosphere_enable(void);
+void raydium_sky_atmosphere_enable	(void);
 /**
 turn on the use of atmosphere effects.
-This one and _disable function a program should use, the other ##raydium_atmosphere_##
+This one and _disable function a program should use, the other ##raydium_sky_atmosphere_##
 are internal ones.
 **/
 
-void raydium_atmosphere_disable(void);
+void raydium_sky_atmosphere_disable	(void);
 /**
 turn off the use of atmosphere effects.
 **/
 
-void raydium_atmosphere_render( GLfloat x, GLfloat y, GLfloat z,int detail);
+void raydium_sky_atmosphere_render	(GLfloat x, GLfloat y, GLfloat z,int detail);
 /**
 Internal use. This internal function draws the atmosphere effects. Right now only draws a
 rotating sphere with a gradient of color (from black to white).
@@ -68,7 +68,7 @@
 **/
 
 
-char raydium_atmosphere_check();
+char raydium_sky_atmosphere_check	(void);
 /**
 This functions only check if the atmosphere features are been used. 
 Returns 1 if they are used, else 0.
@@ -40,26 +40,26 @@
 If you need to check if the atmosphere is activated or not, use 
-##raydium_atmosphere_check##. The rest of the functions are internal and should
+##raydium_sky_atmosphere_check##. The rest of the functions are internal and should
 not used by normal programs.
 